@@ -47,7 +47,7 @@ answer_to_connection (void *cls, struct MHD_Connection *connection,
         return MHD_NO;
     }
   response =
-    MHD_create_response_from_fd_at_offset (fd, sbuf.st_size, 0);
+    MHD_create_response_from_fd_at_offset (sbuf.st_size, fd, 0);
   MHD_add_response_header (response, "Content-Type", MIMETYPE);
   ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
   MHD_destroy_response (response);
