@@ -33,7 +33,11 @@
 #include <gnutls/gnutls.h>
 #endif
 
-#define EXTRA_CHECKS MHD_YES
+/**
+ * Should we perform additional sanity checks at runtime (on our internal
+ * invariants)?  This may lead to aborts, but can be useful for debugging.
+ */
+#define EXTRA_CHECKS MHD_NO
 
 #define MHD_MAX(a,b) ((a)<(b)) ? (b) : (a)
 #define MHD_MIN(a,b) ((a)<(b)) ? (a) : (b)
@@ -526,7 +530,7 @@ struct MHD_Connection
    * Foreign address (of length addr_len).  MALLOCED (not
    * in pool!).
    */
-  struct sockaddr_in *addr;
+  struct sockaddr *addr;
 
   /**
    * Thread for this connection (if we are using
