@@ -122,8 +122,9 @@ ahc_echo (void *cls,
       *done = 1;
       return MHD_YES;
     }
-  response = MHD_create_response_from_data (strlen (url),
-                                            (void *) url, MHD_NO, MHD_YES);
+  response = MHD_create_response_from_buffer (strlen (url),
+					      (void *) url, 
+					      MHD_RESPMEM_MUST_COPY);
   ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
   MHD_destroy_response (response);
   return ret;
